@@ -2,6 +2,7 @@ import tempfile
 import time
 from argparse import Namespace
 
+import serial.tools.list_ports
 from colorama import Fore
 from mpremote.main import State, argparse_repl
 from watchdog.observers import Observer
@@ -51,7 +52,7 @@ def sync(port: str, path: str, clean: bool):
     pyb.exit_raw_repl_verbose()
 
 
-def start_dev_mode(port: str, path: str, auto_reset: str):
+def start_dev_mode(port: str, path: str, auto_reset: str, no_prompt: bool):
     path = utils.replace_backslashes(path)
     port = utils.port_abbreviation(port)
     print(Fore.YELLOW, f"- Syncing files on {port} with {path}")
@@ -60,14 +61,14 @@ def start_dev_mode(port: str, path: str, auto_reset: str):
     while True:
         pyb = SweetPyboard(device=port)
         pyb.enter_raw_repl_verbose()
-        pyb.sync_with_dir(dir_path=path)
-        old_ls = utils.recursive_list_dir(path)
-        print(Fore.LIGHTWHITE_EX +
-              " ? Press [Enter] to Sync & Enter REPL\n" +
-              "   Press [Ctrl + C] to exit ", end="")
-        utils.reset_term_color()
-        input()
-        push_deletes(pyb, path, old_ls=old_ls)
+        if not no_prompt:
+            pyb.sync_with_dir(dir_path=path)
+            print(Fore.LIGHTWHITE_EX +
+                  " ? Press [Enter] to Sync & Enter REPL\n" +
+                  "   Press [Ctrl + C] to exit ", end="")
+            utils.reset_term_color()
+            input()
+        pyb.delete_absent_items(dir_path=path)
         pyb.sync_with_dir(dir_path=path)
         if auto_reset is None:
             pyb.exit_raw_repl()
@@ -105,9 +106,19 @@ def start_repl(port: str):
     utils.reset_term_color()
 
 
-def push_deletes(pyb, path, old_ls: tuple):
-    new_ls = utils.recursive_list_dir(path)
-    for file in set(old_ls[1]).difference(new_ls[1]):
-        pyb.fs_verbose_rm(file)
-    for ddir in sorted(set(new_ls[0]).difference(new_ls[0]), reverse=True):
-        pyb.fs_verbose_rmdir(ddir)
+def list_devices():
+    ports = sorted(serial.tools.list_ports.comports())
+    if ports:
+        for i, port in enumerate(ports):
+            print(Fore.LIGHTYELLOW_EX,
+                  "{}. {} {} {:04x}:{:04x} {} {}".format(
+                      i + 1,
+                      port.device,
+                      port.serial_number or "null",
+                      port.vid if isinstance(port.vid, int) else 0,
+                      port.pid if isinstance(port.pid, int) else 0,
+                      port.manufacturer or "null",
+                      port.product or "null"))
+    else:
+        print(Fore.LIGHTYELLOW_EX, "Couldn't find any connected devices")
+    utils.reset_term_color()
